import { defineComponent, h, ref, getCurrentInstance } from "vue";
import { useShikiHighlighted } from "./utils.mjs";
export default defineComponent({
  props: {
    code: String,
    lang: String,
    highlightOptions: Object,
    as: { type: String, default: "pre" },
    unwrap: { type: Boolean, default: void 0 }
  },
  async setup(props) {
    const el = ref();
    const hydratedCode = process.client ? getCurrentInstance()?.vnode?.el?.innerHTML : void 0;
    const highlighted = await useShikiHighlighted(() => props.code, {
      lang: () => props.lang,
      highlighted: hydratedCode,
      unwrap: props.unwrap ?? props.as === "pre",
      ...props.highlightOptions
    });
    return { el, highlighted };
  },
  render() {
    return h(this.as, {
      innerHTML: this.highlighted,
      ref: "el"
    });
  }
});
