import { unwrapTransformer } from "./transforms.mjs";
const _importShikiCore = cached(() => import("shiki/core"));
const _importWasm = cached(() => import("shiki/wasm"));
export const createHighlighter = cached(
  async (_shikiOptions) => {
    const [{ getHighlighterCore }, wasm, shikiOptions] = await Promise.all([
      _importShikiCore(),
      _importWasm(),
      _shikiOptions
    ]);
    const highlighter = await getHighlighterCore({
      ...shikiOptions.core,
      loadWasm: wasm
    });
    highlighter.highlight = (code, highlightOptions) => _highlight(code, highlightOptions, highlighter, shikiOptions);
    return highlighter;
  },
  (args) => {
    const globalCache = globalThis["__nuxt_shiki_cache"] ??= {};
    const key = args[1] || "default";
    return globalCache[key] ??= {};
  }
);
function _highlight(code, highlightOptions, highlighter, shikiOptions) {
  return highlighter.codeToHtml(code, {
    ...shikiOptions.highlight,
    ...highlightOptions,
    lang: highlightOptions.lang || shikiOptions.highlight.lang,
    transformers: [
      ...highlightOptions.unwrap ? [unwrapTransformer] : [],
      ...highlightOptions.transformers || []
    ]
  });
}
function cached(fn, getStore) {
  const _store = getStore ? void 0 : {};
  return function(...args) {
    const store = _store || getStore(args);
    if (store.value !== void 0) {
      return store.value;
    }
    if (store.promise) {
      return store.promise;
    }
    const res = fn(...args);
    if (res instanceof Promise) {
      store.promise = res.then((value) => {
        store.value = value;
        delete store.promise;
        return value;
      });
      return store.promise;
    }
    return store.promise;
  };
}
