import { ref, watch, toValue } from "vue";
import { createHighlighter } from "./shiki.mjs";
export async function getShikiHighlighter() {
  return createHighlighter(
    import("shiki-options.mjs").then((m) => m.shikiOptions),
    "_internal"
  );
}
export async function useShikiHighlighted(code, options = {}) {
  if ("themes" in options && !options.themes) {
    delete options.themes;
  }
  if (import.meta.server) {
    const highlighter = await getShikiHighlighter();
    return ref(highlighter.highlight(toValue(code) || "", {
      ...options,
      lang: toValue(options.lang),
      theme: toValue(options.theme)
    }));
  }
  const highlighted = ref(options.highlighted || "");
  const immediate = !highlighted.value;
  watch([
    () => toValue(code),
    () => toValue(options.lang),
    () => toValue(options.theme)
  ], async ([_code, lang, theme]) => {
    const highlighter = await getShikiHighlighter();
    highlighted.value = highlighter.highlight(_code || "", {
      ...options,
      lang,
      theme
    });
  }, {
    immediate
  });
  return highlighted;
}
export async function loadShikiLanguages(highlighter, ...langs) {
  const { bundledLanguages } = await import("shiki/langs");
  const loadedLanguages = highlighter.getLoadedLanguages();
  await Promise.all(
    langs.filter((lang) => !loadedLanguages.includes(lang)).map((lang) => bundledLanguages[lang]).filter(Boolean).map(
      (dynamicLang) => new Promise((resolve) => {
        dynamicLang().then((loadedLang) => {
          highlighter.loadLanguage(loadedLang).then(() => resolve());
        });
      })
    )
  );
}
